aboutsummaryrefslogtreecommitdiff
path: root/reachability/reachability.go
diff options
context:
space:
mode:
Diffstat (limited to 'reachability/reachability.go')
-rw-r--r--reachability/reachability.go12
1 files changed, 6 insertions, 6 deletions
diff --git a/reachability/reachability.go b/reachability/reachability.go
index 6a0f2583..fd4d00e5 100644
--- a/reachability/reachability.go
+++ b/reachability/reachability.go
@@ -2,21 +2,21 @@ package reachability
import (
commitgraphread "codeberg.org/lindenii/furgit/format/commitgraph/read"
- objectstore "codeberg.org/lindenii/furgit/object/store"
+ objectfetch "codeberg.org/lindenii/furgit/object/fetch"
)
// Reachability provides graph traversal over objects in one object store.
//
// Labels: MT-Safe.
type Reachability struct {
- store objectstore.Reader
- graph *commitgraphread.Reader
+ fetcher *objectfetch.Fetcher
+ graph *commitgraphread.Reader
}
// New builds a Reachability over one object store with an optional
// commit-graph reader for faster commit-domain traversal.
//
// Labels: Deps-Borrowed, Life-Parent.
-func New(store objectstore.Reader, graph *commitgraphread.Reader) *Reachability {
- return &Reachability{store: store, graph: graph}
+func New(fetcher *objectfetch.Fetcher, graph *commitgraphread.Reader) *Reachability {
+ return &Reachability{fetcher: fetcher, graph: graph}
}
@@ -2,21 +2,21 @@ package reachability
}
-// New builds a Reachability over one object store with an optional
+// New builds a Reachability over one object fetcher with an optional
// commit-graph reader for faster commit-domain traversal.
//